#
# spec file for package gnome-user-share
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-user-share
Version:        48.0
Release:        1.1
Summary:        GNOME user file sharing
License:        GPL-2.0-or-later
Group:          Productivity/Networking/File-Sharing
URL:            https://gitlab.gnome.org/GNOME/gnome-user-share
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst

BuildRequires:  cargo-packaging
BuildRequires:  clang
BuildRequires:  fdupes
BuildRequires:  meson >= 0.50.0
BuildRequires:  pkgconfig
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(glib-2.0) >= 2.58
BuildRequires:  pkgconfig(libcanberra-gtk3)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(systemd)
Suggests:       apache2-prefork
Suggests:       apache2-worker

%description
gnome-user-share is a small package that binds together various free
software projects to bring easy to use user-level file sharing to the
masses.

The program is meant to run in the background when the user is logged
in, and when file sharing is enabled a webdav server is started that
shares the $HOME/Public folder. The share is then published to all
computers on the local network using mDNS/rendezvous, so that it shows
up in the Network location in GNOME.

%lang_package

%prep
%autosetup -p1 -a1

%build
%meson \
	--buildtype=release \
	--libexecdir=%{_libexecdir}/gnome-user-share \
	-Dmodules_path=%{_libdir}/apache2/ \
	-Dsystemduserunitdir=%{_userunitdir} \
	%{nil}
%meson_build

%install
%meson_install

%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_prefix}

%check
%meson_test

%files
%license COPYING
%doc README.md NEWS
%{_libexecdir}/gnome-user-share
%{_datadir}/gnome-user-share
%{_datadir}/applications/gnome-user-share-webdav.desktop
%dir %{_datadir}/GConf
%dir %{_datadir}/GConf/gsettings
%{_datadir}/GConf/gsettings/gnome-user-share.convert
%{_datadir}/glib-2.0/schemas/org.gnome.desktop.file-sharing.gschema.xml
%{_userunitdir}/gnome-user-share-webdav.service

%files lang -f %{name}.lang

%changelog
* Sun Mar 16 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.0:
  + Turn some exceptions into exiting with a warning
  + Various CI and build tweaks
  + Fix gettext string not being parsed correctly
  + Port the project code from C to the Rust language
  + Make systemd an optional dependency
  + Fix a compiling issue for non-gnu C toolchain
  + Updated translations.
- Add clang and cargo-packaging BuildRequires and new vendor
  tarball following upstreams port to rust.
- Pass buildtype=release to meson setup, ensure we build optimized
  release and not devel.
* Thu Jan 23 2025 pgajdos@suse.com
- do not suggest apache2-mod_dnssd, which is no longer part of
  Factory
* Mon Nov 25 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Adjust _service definition: upstream has changed their tag format
  to be a simple VERSION tag.
* Sat Nov 23 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.2:
  + Fix a compiling issue for non-gnu C toolchain.
* Sun Sep 15 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.0:
  + Updated translations.
* Mon Aug 26 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.alpha:
  + Increase the required Apache web server version to 2.4
  + Remove GNOME 2 migration code
  + Remove the size limit for file transfers
  + Fix leaks
  + Updated translations.
* Fri Oct 13 2023 bjorn.lie@gmail.com
- Update to version 43.0+11:
  * DOAP: Fix 'bug-database' value to point to GNOME GitLab Issues
  * Updated translations.
- Update URL to new home.
* Fri Sep 16 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.0:
  + Updated translations.
* Sat Aug  6 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.alpha:
  + Remove Nautilus extension.
  + Fix build with meson 0.61 and newer.
  + Updated translations.
- Drop gnome-user-share-fix-meson-0_61_0.patch fixed upstream.
- Drop pkgconfig(libnautilus-extension) and pkgconfig(gtk+-3.0)
  BuildRequires: No longer needed as nautilus extension was removed
  upstream.
- Drop obsolete glib2_gsettings_schema_requires macro.
* Tue Feb  1 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.0+25:
  + build: correct gio_unix_dep use.
  + Updated translations.
- Switch to gitcheckout via source service, upstream is not making
  releases, and we want the translations.
- Add gnome-user-share-fix-meson-0_61_0.patch: Fix build with meson
  0.61.0 and newer.
- Drop update-desktop-files BuildRequires and its macro, no longer
  needed.
- Stop removing non-existant la files, not built since the switch
  to meson buildsystem.
* Mon Sep 20 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Fri Sep  6 2019 mgorse@suse.com
- Update to version 3.34.0:
  + Fix installation location of systemd unit file on Fedora 64-bit
    systems.
  + Updated translations.
* Sat Aug 31 2019 mgorse@suse.com
- Update to version 3.33.1:
  + Port to meson build system.
  + Remove autotools as build system.
- Add meson BuildRequires and macros.
* Mon Mar 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0.1:
  + Work-around a gettext bug that caused the "NoDisplay" property
    to be dropped from the .desktop file.
  + Updated translations.
* Thu Mar  7 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Fix name in nautilus extension.
  + Build fixes, including intltool dependency removal.
  + Updated translations.
- Drop intltool BuildRequires: No longer needed.
- Drop post(un) handling, file-triggers takes care of this for us
  now.
* Mon May 14 2018 fcrozat@suse.com
- Remove dependency on bluez and adapt description,
  gnome-user-share doesn't handle OBEX anymore, it is done by
  gnome-bluetooth nowadays.
* Tue Apr 10 2018 bjorn.lie@gmail.com
- Update to version 3.28.0:
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Wed Feb 14 2018 dimstar@opensuse.org
- Update to version 3.27.90:
  + Update for nautilus changes in 3.28 development branch.
* Tue Sep 20 2016 zaitor@opensuse.org
- Update to version 3.18.3:
  + Fix possible unexpanded path in .desktop file.
* Wed Aug 31 2016 zaitor@opensuse.org
- Update to version 3.18.2:
  + Add a way for gnome-user-share to be started via user systemd.
- Add pkgconfig(systemd) BuildRequies: New dependency.
* Tue May  3 2016 fcrozat@suse.com
- Update to GNOME 3.20  Fate#318572
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.18.1:
  + Updated translations.
* Mon Sep 21 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Tue Sep 15 2015 zaitor@opensuse.org
- Update to version 3.17.92:
  + Updated translations.
* Mon Aug 17 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Remove ObexPush support, it's now available directly in the
    gnome-bluetooth Settings widget.
  + Better explanation when in Public folder.
  + Updated translations.
- Remove pkgconfig(gnome-bluetooth-1.0) BuildRequires: No longer
  needed since ObexPush support was removed.
* Thu Dec 18 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + Fix crasher in gsettings-data-convert.
  + Updated translations.
* Fri Nov 21 2014 zaitor@opensuse.org
- Update to version 3.14.1:
  + Always hide the info bar in Downloads.
  + Don't talk of "sharing over Bluetooth" since ObexFTP support
    was removed.
  + Make sure obexd daemon is launched when ObexPUSH is enabled.
  + Make sure that Bluetooth notifications don't time out.
  + Fix launching obexpush and webdav sharing at the same time.
  + Updated translations.
* Mon Sep 22 2014 zaitor@opensuse.org
- Update to version 3.14.0:
  + Updated translations.
* Thu Sep 11 2014 dimstar@opensuse.org
- Update to version 3.13.91:
  + Fix compilation with Bluetooth disabled.
  + Updated translations.
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 3.13.2:
  + Fix launching the webdav server.
- Changes from version 3.13.1:
  + Integrate with the new sharing system in gnome-settings-daemon.
  + Fix server errors with require_password=never.
- No longer pass sed --disable-schemas-install and
  - -disable-scrollkeeper to configure: they were no longer valid
  since version 3.0.3.
* Tue Mar 18 2014 dimstar@opensuse.org
- Update to version 3.10.2:
  + Fix race condition when moving to Downloads dir.
  + Fix notifications not working.
  + Reject transfers in one place.
  + Remove temp files when rejecting transfers.
  + Enable notifications by default.
  + Use FileManager1 XDG API to reveal file.
  + Fix launch context leak.
  + Use correct desktop-entry hint.
  + Use Bluetooth icon for notifications.
  + Fix agent not working when restarting obexd.
  + Remove the status icon.
  + Updated translations.
* Wed Nov 20 2013 dimstar@opensuse.org
- Replace obex-data-server Requires with bluez: we rely on
  org.bluez.obex service since the port to bluez5.
* Tue Nov 12 2013 dimstar@opensuse.org
- Update to version 3.10.1 (bnc#849913):
  + Fix share bar bugs that could make nautilus crash.
  + Update share bar labels to match new Sharing panel.
  + Remove unimplemented OBEX FTP support code.
  + Remove dbus-glib dependency.
  = Fix failure to receive files through OBEX Push (bnc#850083).
  = Fix crash when switching VTs.
  + Fix use-after-free bug.
  + Fix a few memory leaks.
  + Re-enable Bluetooth support by default.
- Drop gnome-user-share-downloads-nautilus-crash.patch: fixed
  upstream.
- Drop pkgconfig(dbus-1) and  pkgconfig(dbus-glib-1) BuildRequires:
  no longer needed after the upstream cleanup.
* Tue Sep 24 2013 dimstar@opensuse.org
- Add gnome-user-share-downloads-nautilus-crash.patch: Do not
  crash nautilus when entering 'Downloads' location (bnc#841659,
  bgo#708530, bgo#708456).
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Wed Sep  4 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + Port to Bluez 5.
  + Updated translations.
* Mon Jul 15 2013 dimstar@opensuse.org
- Update to version 3.8.3:
  + Fix the servers not starting when enabled in System Settings's
    sharing panel.
  + Fix race condition for the personal files sharing on OpenBSD.
- Use suse_update_desktop_files against the newly installed
  gnome-user-share-(webdav|obexftp|obexpush).desktop files.
* Mon Mar 25 2013 zaitor@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
* Tue Mar  5 2013 dimstar@opensuse.org
- Update to version 3.7.91:
  + Add support for logind seat-tracking using gnome-session.
  + Add support for Apache HTTPD 2.4.
  + Updated translations.
* Wed Feb 20 2013 dimstar@opensuse.org
- Update to version 3.7.90:
  + Build .tar.xz tarballs by default.
  + Updated translations.
* Tue Jan 15 2013 dimstar@opensuse.org
- Update to version 3.7.4:
  + Remove preferences as they're now integrated with
    gnome-control-center 3.7.4.
- Drop gnome-user-share-soft-dep-apache.patch: no longer applies,
  as we don't have a properties dialog anymore.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 3.0.4:
  + Hide the share bar when Bluetooth is disabled
  + Updated translations.
* Fri Aug 24 2012 dimstar@opensuse.org
- Update to version 3.0.3:
  + Remove markup from translatable strings
  + Update the appearance of the info bar
  + Make gnome-shell pick up the program's name
  + Port to GSettings
- Replace gnome-doc-utils-devel BuildRequires with yelp-tools,
  following upstreams changes.
- Drop pkgconfig(gconf-2.0) BuildRequires: no longer needed after
  the port to GSettings.
- Replace gconf_* schema handling with glib2_* variants.
* Thu Mar 22 2012 vuntz@opensuse.org
- Update to version 3.0.2:
  + Port from libunique to GtkApplication
  + Add missing string.h include
  + Build cleanups
  + Updated translations.
- Remove pkgconfig(unique-3.0) BuildRequires: dropped upstream.
- Drop gnome-user-share-includes.patch: fixed upstream.
* Sun Nov 27 2011 dimstar@opensuse.org
- Add gnome-user-share-includes.patch: Include string.h to have
  strcmp defined.
* Fri Oct 28 2011 badshah400@gmail.com
- Replace category SystemSetup by X-SuSE-ControlCenter-Personal to
  suppress rpmlint warnings
* Wed Oct 26 2011 badshah400@gmail.com
- Change categories of .desktop file to make it appear grouped with
  "System" applications in the desktop menus (bnc#714333)
* Mon Oct 17 2011 dimstar@opensuse.org
- Update to version 3.0.1:
  + Work-around Linux 3.0 regression that caused the file sharing
    not to work.
  + Updated translations.
* Mon Apr 25 2011 vuntz@opensuse.org
- Move to pkgconfig()-style BuildRequires:
  + Old ones: dbus-1-glib-devel, gconf2-devel,
    gnome-bluetooth-devel, gtk3-devel, libcanberra-devel,
    libnotify-devel, libunique-devel, nautilus-devel.
  + New ones: dbus-1, dbus-glib-1, gconf-2.0, glib-2.0,
    gnome-bluetooth-1.0, gtk+-3.0, libcanberra-gtk3,
    libnautilus-extension, libnotify, unique-3.0.
* Mon Apr  4 2011 fcrozat@novell.com
- Update to version 3.0.0:
  + Updated translations.
- Update to version 2.91.6:
  + Build against GTK+ 3.x
- Change gtk2-devel BuildRequires to gtk3-devel.
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Tue Dec 14 2010 vuntz@opensuse.org
- Own /usr/share/gnome and /usr/share/gnome/help to fix build.
* Tue Sep 28 2010 vuntz@opensuse.org
- Update to version 2.30.1:
  + Fix compilation failure
  + Updated translations.
* Mon Sep  6 2010 vuntz@opensuse.org
- Make gnome-user-share-properties.desktop appear where it should
  in the menu, by replacing the categories: X-GNOME-NetworkSettings
  needs to be removed, and we want X-GNOME-PersonalSettings
  instead.
* Tue Aug  3 2010 vuntz@opensuse.org
- Update gnome-user-share-soft-dep-apache.patch: the name of the
  widget to hide when apache is not there has changed.
* Mon Mar 29 2010 vuntz@opensuse.org
- Update to version 2.30.0:
  + Updated translations.
* Tue Mar 23 2010 dimstar@opensuse.org
- Remove en@shaw locale on openSUSE <= 11.2.
* Mon Mar 15 2010 dimstar@opensuse.org
- Update to version 2.29.92:
  + Fix extension conflicting with nautilus-share's.
* Fri Feb 26 2010 dimstar@opensuse.org
- Update to version 2.29.91:
  + Add a helper bar in nautilus to enable/disable sharing
  + Add sound notification of files being received
  + Don't use Bonded and trusted terms in the UI
  + and many other fixes
- BuildRequire nautilus-devel.
* Wed Dec 23 2009 vuntz@opensuse.org
- Update to version 2.28.2:
  + Avoid crashing on exit()
  + Make preferences single-instance
- Add libunique-devel BuildRequires.
* Sat Nov 14 2009 vuntz@opensuse.org
- Update to version 2.28.1:
  + Play a sound when receiving a file over ObexPush
  + Updated translations.
- Add libcanberra-devel BuildRequires.
* Wed Sep 23 2009 dimstar@opensuse.org
- Update to version 2.28.0:
  + Fix WebDAV share name being untranslated
  + Updated translations.
* Mon Sep  7 2009 lmedinas@opensuse.org
- Update to version 2.27.0:
  + Fix WebDAV sharing not working when service names are too long
  + Fix login problems to WebDAV
  + Don't error out if the Obex services are already started
  + Fix Obex services not working any more when bluetoothd is
    exited
  + UI fixes for rejected ObexPush transfers
  + Updated translations
- Add gnome-bluetooth-devel BuildRequires
* Tue May 19 2009 vuntz@novell.com
- Add Suggests on apache2-mod_dnssd now that it's packaged.
* Mon Mar 16 2009 vuntz@novell.com
- Update to version 2.26.0:
  + Updated translations.
* Fri Mar  6 2009 vuntz@novell.com
- Update to version 2.25.92:
  + Updated translations.
* Thu Feb  5 2009 vuntz@novell.com
- Update to version 2.25.91:
  + Fix httpd configuration file
- Changes from version 2.26.90:
  + Use mod_dnssd 0.6 to export the user TXT record, necessary to
    work with the latest gvfs
  + Check for httpd version and binary location at run-time, rather
    than compile-time
  + Documentation updates
- Changes from version 0.41:
  + Use Apache's mod_dnssd module instead of doing the work
    ourselves
  + Refuse to run as root, so as to avoid sensitive files being
    shared
  + Add end-user documentation, and UI changes to match
  + Make it possible for build daemons to build without Apache
    installed
- Remove BuildRequires on apache2-prefork: we can build without
  having apache installed now.
- Remove BuildRequires on libavahi-glib-devel: this is not needed
  anymore: mod_dnssd is now used.
- Add gnome-doc-utils-devel BuildRequires.
- Do not call autoreconf.
- Use fdupes.
* Sat Dec 20 2008 mboman@suse.de
- Update to version 0.41:
  + Port to BlueZ 4.x API
  + UI fixes in the preferences dialogue
  + Fix web file sharing on some distributions
- Remove gnome-user-share-bluez4.patch. Fixed upstream
- Remove gnome-user-share-httpd-detection.patch. Fixed upstream
* Tue Dec 16 2008 coolo@suse.de
- require lang subpackage
* Mon Nov 24 2008 vuntz@novell.com
- Use %%{_libdir} for the httpd module directory. Fix bnc#448129.
* Sat Nov 22 2008 aj@suse.de
- Fix package list to fix build.
- gnome-user-share helper is a binary, put it into libexecdir.
* Wed Nov 19 2008 vuntz@novell.com
- Import package, based on the one from Fedora. Required to fix
  bnc#402048.
